@@ -71,7 +71,7 @@ class NeoStat(SimpleNamespace):
         for a in self._simple_attrs:
             data_attr = a.upper()
             if not hasattr(self._data_, data_attr):
-              self._logger.debug(f"Thermostat object has no attribute {data_attr}")
+                self._logger.debug(f"Thermostat object has no attribute {data_attr}")
             self.__dict__[a] = getattr(self._data_, data_attr, None)
 
         # Renamed attrs
@@ -98,6 +98,19 @@ class NeoStat(SimpleNamespace):
         _time = datetime.strptime(self.time, "%H:%M")
         self.time = timedelta(hours=_time.hour, minutes=_time.minute)
 
+    def __str__(self):
+        """
+        String representation.
+        """
+        data_elem = []
+        for elem in dir(self):
+            if not callable(getattr(self, elem)) and not elem.startswith('_'):
+                data_elem.append(elem)
+        out = 'HeatMiser NeoStat (%s):\n' % (self.name)
+        for elem in data_elem:
+            out += ' - %s: %s\n' % (elem, getattr(self, elem))
+        return out
+
     async def identify(self):
         """
         Flashes red LED light
